import{e}from"./index-B4UsuA0L.js";import{d as r,b as o,ae as n,u as c,h as l,e as d}from"./lucide-8Ndi-dzR.js";const m=r({__name:"CardDescription",props:{class:{type:[Boolean,null,String,Object,Array]}},setup(a){const s=a;return(t,p)=>(d(),o("p",{"data-slot":"card-description",class:n(c(e)("text-muted-foreground text-sm",s.class))},[l(t.$slots,"default")],2))}}),_=r({__name:"CardHeader",props:{class:{type:[Boolean,null,String,Object,Array]}},setup(a){const s=a;return(t,p)=>(d(),o("div",{"data-slot":"card-header",class:n(c(e)("@container/card-header grid auto-rows-min grid-rows-[auto_auto] items-start gap-1.5 px-6 has-data-[slot=card-action]:grid-cols-[1fr_auto] [.border-b]:pb-6",s.class))},[l(t.$slots,"default")],2))}}),f=r({__name:"CardTitle",props:{class:{type:[Boolean,null,String,Object,Array]}},setup(a){const s=a;return(t,p)=>(d(),o("h3",{"data-slot":"card-title",class:n(c(e)("leading-none font-semibold",s.class))},[l(t.$slots,"default")],2))}});export{_,f as a,m as b};
